@@ -6,10 +6,17 @@ import unittest
 import pydantic
 
 from aind_data_schema import EphysRig, EphysSession
-from aind_data_schema.ephys.ephys_rig import (LaserModule, Manipulator,
-                                              ManipulatorAngle)
-from aind_data_schema.ephys.ephys_session import (CcfCoords, Coordinates3d,
-                                                  EphysProbe, Stream)
+from aind_data_schema.ephys.ephys_rig import (
+    LaserModule,
+    Manipulator,
+    ManipulatorAngle,
+)
+from aind_data_schema.ephys.ephys_session import (
+    CcfCoords,
+    Coordinates3d,
+    EphysProbe,
+    Stream,
+)
 
 
 class ExampleTest(unittest.TestCase):
